==> routedocs-0.1.0-20191101.131639-5.jar: META-INF/leiningen/com.zimpler/routedocs/project.clj <==
(defproject com.zimpler/routedocs "0.1.0-SNAPSHOT"

  :description "Lightweight docs for Compojure routes"
  :url "https://github.com/Zimpler/routedocs"
  :license {:name "Eclipse Public License"
            :url "http://www.eclipse.org/legal/epl-v10.html"}

  :dependencies [[org.clojure/clojure "1.10.1" :scope "provided"]
                 [compojure "1.6.1" :scope "provided"]
                 [markdown-clj "1.10.0"]]                          ;; https://github.com/yogthos/markdown-clj

  :plugins      [[lein-pprint "1.2.0"]]

  ;:repositories ^:replace [["clojars" {:url "https://clojars.org/repo"
  ;                                     :username ~(System/getenv "CLOJARS_USERNAME")
  ;                                     :password ~(System/getenv "CLOJARS_PASSWORD")
  ;                                     :sign-releases false}]]

  ;:repositories [["clojars" {:url "https://clojars.org/repo/"
  ;                           :username ~(System/getenv "CLOJARS_USERNAME")
  ;                           :password ~(System/getenv "CLOJARS_PASSWORD")
  ;                           :sign-releases false}]]

                 ;["my-releases" {:url "https://clojars.org/repo/"
                 ;                :username :env/clojars_username
                 ;                :password :env/clojars_password
                 ;                :sign-releases false}]
                 ;["my-snapshots" {:url "https://clojars.org/repo/"
                 ;                 :username :env/clojars_username
                 ;                 :password :env/clojars_password
                 ;                 :sign-releases false}]]

  :deploy-repositories  [["clojars" {:url "https://clojars.org/repo/"
                                     :username ~(System/getenv "CLOJARS_USERNAME")
                                     :password ~(System/getenv "CLOJARS_PASSWORD")
                                     :sign-releases false}]
                         ;["clojars"   {:url "https://clojars.org/repo"
                         ;              :username ~(System/getenv "CLOJARS_USERNAME")
                         ;              :password ~(System/getenv "CLOJARS_PASSWORD")
                         ;              :sign-releases false}]
                         ;["clojars" {:url "https://clojars.org/repo"
                         ;            :username :env/clojars_username
                         ;            :password :env/clojars_password
                         ;            :sign-releases false}]
                         ;["snapshots" {:url "https://clojars.org/repo"
                         ;              :username :env/clojars_username
                         ;              :password :env/clojars_password
                         ;              :sign-releases false}]
                         ;["releases" {:url "https://clojars.org/repo"
                         ;             :username :env/clojars_username
                         ;             :password :env/clojars_password
                         ;             :sign-releases false}]]
                         ["snapshots" :clojars]
                         ["releases"  :clojars]]
                         ;["clojars"
                         ; {:url "https://clojars.org/repo/", :password "4@&T3eC%#tEM8RT", :username "zimpler"}]
                         ;["snapshots"
                         ;  {:url "https://clojars.org/repo/", :password "4@&T3eC%#tEM8RT", :username "zimpler"}]
                         ;["releases"
                         ;  {:url "https://clojars.org/repo/",
                         ;   :password "4@&T3eC%#tEM8RT",
                         ;   :username "zimpler"}]]

;["releases"  {:url "https://clojars.org/repo"
                                               ;              :username :env/clojars_username
                                               ;              :password :env/clojars_password
                                               ;              :sign-releases false}]]

  :source-paths    ["src/clj"]
  :target-path     "target/%s"

  :profiles {:dev {:dependencies [[org.clojure/clojure "1.10.1"]
                                  [compojure "1.6.1"]
                                  [ring "1.7.1"]]}
             ;:auth {
             ;       :repositories ^:replace [["repo" {:url "https://clojars.org/repo/"
             ;                                         :username #=(eval (System/getenv "CLOJARS_USERNAME"))
             ;                                         :password #=(eval (System/getenv "CLOJARS_PASSWORD"))
             ;                                         :sign-releases false}]]
             ;       :repository-auth ^:replace {#"https://clojars.org/repo"  {:username "zimpler",
             ;                                                                 :password "4@&T3eC%#tEM8RT",
             ;                                                                 :sign-releases false}}}

             :test {:test-paths ["src_test/clj"]
                    :jvm-opts   ["-Dorg.eclipse.jetty.LEVEL=OFF"]}})

             ;:auth {:repository-auth {#"https://clojars.org/repo" ^:replace {:username "zimpler",
             ;                                                                :password "4@&T3eC%#tEM8RT",
             ;                                                                :sign-releases false}}}})

==> routedocs-0.1.0-20191101.131726-6.jar: META-INF/leiningen/com.zimpler/routedocs/project.clj <==
(defproject com.zimpler/routedocs "0.1.0-SNAPSHOT"

  :description "Lightweight docs for Compojure routes"
  :url "https://github.com/Zimpler/routedocs"
  :license {:name "Eclipse Public License"
            :url "http://www.eclipse.org/legal/epl-v10.html"}

  :dependencies [[org.clojure/clojure "1.10.1" :scope "provided"]
                 [compojure "1.6.1" :scope "provided"]
                 [markdown-clj "1.10.0"]]                          ;; https://github.com/yogthos/markdown-clj

  :plugins      [[lein-pprint "1.2.0"]]


  :deploy-repositories  [
                         ;["clojars" {:url "https://clojars.org/repo/"
                         ;            :username ~(System/getenv "CLOJARS_USERNAME")
                         ;            :password ~(System/getenv "CLOJARS_PASSWORD")
                         ;            :sign-releases false}]
                         ["clojars" {:url "https://clojars.org/repo"
                                     :username :env/clojars_username
                                     :password :env/clojars_password
                                     :sign-releases false}]
                         ["snapshots" :clojars]
                         ["releases"  :clojars]]
                         ;["clojars"
                         ; {:url "https://clojars.org/repo/", :password "4@&T3eC%#tEM8RT", :username "zimpler"}]
                         ;["snapshots"
                         ;  {:url "https://clojars.org/repo/", :password "4@&T3eC%#tEM8RT", :username "zimpler"}]
                         ;["releases"
                         ;  {:url "https://clojars.org/repo/",
                         ;   :password "4@&T3eC%#tEM8RT",
                         ;   :username "zimpler"}]]

;["releases"  {:url "https://clojars.org/repo"
                                               ;              :username :env/clojars_username
                                               ;              :password :env/clojars_password
                                               ;              :sign-releases false}]]

  :source-paths    ["src/clj"]
  :target-path     "target/%s"

  :profiles {:dev {:dependencies [[org.clojure/clojure "1.10.1"]
                                  [compojure "1.6.1"]
                                  [ring "1.7.1"]]}
             ;:auth {
             ;       :repositories ^:replace [["repo" {:url "https://clojars.org/repo/"
             ;                                         :username #=(eval (System/getenv "CLOJARS_USERNAME"))
             ;                                         :password #=(eval (System/getenv "CLOJARS_PASSWORD"))
             ;                                         :sign-releases false}]]
             ;       :repository-auth ^:replace {#"https://clojars.org/repo"  {:username "zimpler",
             ;                                                                 :password "4@&T3eC%#tEM8RT",
             ;                                                                 :sign-releases false}}}

             :test {:test-paths ["src_test/clj"]
                    :jvm-opts   ["-Dorg.eclipse.jetty.LEVEL=OFF"]}})

             ;:auth {:repository-auth {#"https://clojars.org/repo" ^:replace {:username "zimpler",
             ;                                                                :password "4@&T3eC%#tEM8RT",
             ;                                                                :sign-releases false}}}})
